import { CustomWorld } from './custom_world';
import { StepsWorld } from './steps_world';
import * as AnnotationMetadata from '../support/annotation_metadata';
import { Metadata as ScenarioMetadata } from '../support/scenario_metadata';
declare class WorldsCollection extends Map<String, AnnotatedWorld> {
    create(customWorld: CustomWorld): void;
    getWorldByConstructor(worldConstructor: Function): AnnotatedWorld;
    getWorldByMeta(worldMeta: AnnotationMetadata.WorldMeta): AnnotatedWorld;
    dispatchMetadata(metadata: ScenarioMetadata): void;
}
export declare const WorldsMap: WorldsCollection;
export declare class AnnotatedWorld {
    readonly worldConstructor: AnnotationMetadata.WorldConstructor;
    readonly name: string;
    constructor(worldConstructor: AnnotationMetadata.WorldConstructor);
    protected instance: StepsWorld | null;
    protected customWorld: CustomWorld | null;
    readonly world: StepsWorld | null;
    create(customWorld: CustomWorld): void;
    dispatchMetadata(metadata: ScenarioMetadata): void;
    /**
     * wrapper for a steps world method, so that it will report the correct arity to CucumberJS, as CucumberJS's Step runner
     * actively checks the length property to match the number of found parameters in the pattern
     * @param stepName
     * @param stepMethodName
     * @param arity
     */
    createDelegatedCucumberJSMethod(stepMethodName: string, stepMethod: Function): (this: CustomWorld, ...args: any[]) => void;
}
export {};
