"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CucumberJS = require("cucumber");
const chai_1 = require("chai");
require("../worlds/custom_world");
const AnnotationMetadata = require("../support/annotation_metadata");
const annotated_world_1 = require("../worlds/annotated_world");
/** Register the following method as a Cucumber "before all scenarios" callback
 *  The method *must* be static */
function BeforeAll(options = {}) {
    console.log('Before all with', options);
    return (worldMeta, stepMethodName, descriptor) => {
        checkAllScenariosMethod(worldMeta, 'Before', stepMethodName, descriptor.value);
        CucumberJS.BeforeAll.call(null, options, descriptor.value);
    };
}
exports.BeforeAll = BeforeAll;
/** Register the following method as a Cucumber "before each scenario" callback
 *  the method may *not* be static */
function Before(options = {}) {
    return (worldMeta, stepMethodName, descriptor) => {
        checkEachScenariosMethod(worldMeta, 'Before', stepMethodName, descriptor.value);
        CucumberJS.Before(options, annotated_world_1.WorldsMap.getWorldByMeta(worldMeta).createDelegatedCucumberJSMethod(stepMethodName, descriptor.value));
    };
}
exports.Before = Before;
/** Register the following method as a Cucumber "after each scenario" callback
 *  the method may *not* be static */
function After(options = {}) {
    return (worldMeta, stepMethodName, descriptor) => {
        checkEachScenariosMethod(worldMeta, 'After', stepMethodName, descriptor.value);
        console.log('Add stepsworld After');
        CucumberJS.After(options, annotated_world_1.WorldsMap.getWorldByMeta(worldMeta).createDelegatedCucumberJSMethod(stepMethodName, descriptor.value));
    };
}
exports.After = After;
/** Register the following method as a Cucumber "after all scenarios" callback
 *  The method *must* be static */
function AfterAll(options = {}) {
    return (worldMeta, stepMethodName, descriptor) => {
        checkAllScenariosMethod(worldMeta, 'After', stepMethodName, descriptor.value);
        CucumberJS.AfterAll.call(null, options, descriptor.value);
    };
}
exports.AfterAll = AfterAll;
function checkAllScenariosMethod(worldMeta, hookDesignator, methodName, method) {
    const info = `${hookDesignator} all scenarios hook ${AnnotationMetadata.metaGetName(worldMeta, methodName)}`;
    AnnotationMetadata.assertMethodConvention(worldMeta, info, true);
    chai_1.expect(method.length, `${info} may not have parameters.`).to.be.lessThan(1);
}
function checkEachScenariosMethod(worldMeta, hookDesignator, methodName, method) {
    const info = `${hookDesignator} each scenarios hook ${AnnotationMetadata.metaGetName(worldMeta, methodName)}`;
    AnnotationMetadata.assertMethodConvention(worldMeta, info, false);
    chai_1.expect(method.length, `${info} may accept at most one parameter.`).to.be.lessThan(2);
}
//# sourceMappingURL=hooks.js.map