"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const steps_world_1 = require("./steps_world");
const AnnotationMetadata = require("../support/annotation_metadata");
class WorldsCollection extends Map {
    create(customWorld) {
        this.forEach((annotatedWorld) => annotatedWorld.create(customWorld));
    }
    getWorldByConstructor(worldConstructor) {
        return this.getWorldByMeta(worldConstructor);
    }
    getWorldByMeta(worldMeta) {
        const constructor = AnnotationMetadata.getConstructor(worldMeta);
        let result = this.get(constructor.name);
        if (result == undefined) {
            result = new AnnotatedWorld(constructor);
            this.set(constructor.name, result);
        }
        return result;
    }
    dispatchMetadata(metadata) {
        this.forEach((annotatedWorld) => annotatedWorld.dispatchMetadata(metadata));
    }
}
exports.WorldsMap = new WorldsCollection();
class AnnotatedWorld {
    constructor(worldConstructor) {
        this.worldConstructor = worldConstructor;
        this.instance = null;
        this.customWorld = null;
        this.name = worldConstructor.name;
    }
    get world() { return this.instance; }
    create(customWorld) {
        this.customWorld = customWorld;
        this.instance = new this.worldConstructor();
    }
    dispatchMetadata(metadata) {
        steps_world_1.StepsWorld.prototype.setMetadata.call(this.instance, metadata);
    }
    /**
     * wrapper for a steps world method, so that it will report the correct arity to CucumberJS, as CucumberJS's Step runner
     * actively checks the length property to match the number of found parameters in the pattern
     * @param stepName
     * @param stepMethodName
     * @param arity
     */
    createDelegatedCucumberJSMethod(stepMethodName, stepMethod) {
        const self = this;
        const result = function (...args) {
            chai_1.expect(this, 'different engines').to.be.equal(self.customWorld);
            chai_1.expect(self.instance, 'World was not created yet').to.be.not.null;
            stepMethod.call(self.instance, ...args);
        };
        Object.defineProperties(result, {
            'length': { value: stepMethod.length },
            'name': { value: `delegate_to_${self.worldConstructor.name}_${stepMethodName}` }
        });
        return result;
    }
}
exports.AnnotatedWorld = AnnotatedWorld;
//# sourceMappingURL=annotated_world.js.map